const os = require('os');
const dotenv = require('dotenv');

dotenv.config();

const config = {
  gcloud: {
    bucket: process.env.GCLOUD_BUCKET,
    hash: process.env.GCLOUD_HASH,
  },
  bcrypt: {
    saltRounds: parseInt(process.env.BCRYPT_SALT_ROUNDS, 10),
  },
  admin_pass: process.env.ADMIN_PASS,
  admin_email: process.env.ADMIN_EMAIL,
  providers: {
    LOCAL: process.env.PROVIDER_LOCAL,
    GOOGLE: process.env.PROVIDER_GOOGLE,
    MICROSOFT: process.env.PROVIDER_MICROSOFT,
  },
  secret_key: process.env.SECRET_KEY,
  remote: process.env.REMOTE,
  port: process.env.REACT_APP_ENV === 'production' ? '' : process.env.PORT,
  hostUI: process.env.REACT_APP_ENV === 'production' ? '' : process.env.HOST_UI,
  portUI: process.env.REACT_APP_ENV === 'production' ? '' : process.env.PORT_UI,
  portUIProd: process.env.REACT_APP_ENV === 'production' ? '/#' : process.env.PORT_UI_PROD,
  swaggerUI: process.env.REACT_APP_ENV === 'production' ? '' : process.env.SWAGGER_UI,
  swaggerPort: process.env.REACT_APP_ENV === 'production' ? '' : process.env.SWAGGER_PORT,
  google: {
    clientId: process.env.GOOGLE_CLIENT_ID,
    clientSecret: process.env.GOOGLE_CLIENT_SECRET,
  },
  microsoft: {
    clientId: process.env.MICROSOFT_CLIENT_ID,
    clientSecret: process.env.MICROSOFT_CLIENT_SECRET,
  },
  uploadDir: os.tmpdir(),
};

config.host =
  process.env.REACT_APP_ENV === 'production' ? config.remote : 'http://localhost';
config.apiUrl = `${config.host}${config.port ? `:${config.port}` : ``}/api`;
config.swaggerUrl = `${config.swaggerUI}${config.swaggerPort}`;
config.uiUrl = `${config.hostUI}${config.portUI ? `:${config.portUI}` : ``}/#`;
config.backUrl = `${config.hostUI}${config.portUI ? `:${config.portUI}` : ``}`;

module.exports = config;