const db = require('../db/models');
const PujarisDBApi = require('../db/api/pujaris');
const Karuser_pujari_mappingsDBApi = require('../db/api/karuser_pujari_mappings')
const ValidationError = require('./notifications/errors/validation');
const WatiService = require('../services/wati');
const EmailSender = require('./email');

module.exports = class PujarisService {
  static async create(data, currentUser) {
    const transaction = await db.sequelize.transaction();
    try {
      const pujariCreateRsponse = await PujarisDBApi.create(data, {
        currentUser,
        transaction,
      });

      const karusersPujariMappings = data?.karusers.map((user) => {
        return {
          pujari_id: pujariCreateRsponse?.id,
          karuser_id: user.id
        };
      })

      await Karuser_pujari_mappingsDBApi.create(karusersPujariMappings, {
        currentUser,
        transaction,
      })
      const watiObj = new WatiService();
      const mailSender = new EmailSender();

      // NOTIFIY ADMIN

      try {
        // WatiService.sendWhatsappMessage(
        //   watiObj.adminPhone,
        //   watiObj.templates.userCreatedAdmin,
        //   [
        //     {
        //       name: 'user_name',
        //       value: `TEST`,
        //     },
        //   ],
        // );
        await mailSender.sendEmail({
          dynamicData: {},
          mailProps: { to: mailSender.adminMail },
          template: mailSender.htmlTemplates.PUJARI_CREATE__ADMIN,
        });

        // NOTIFIY USER

        WatiService.sendWhatsappMessage(
          data.phone_number,
          watiObj.templates.pujariCreated,
          [
            {
              name: 'name',
              value: `${data.name} ${data.surname}`,
            },
          ],
        );

        // await mailSender.sendEmail({
        //   dynamicData: {},
        //   mailProps: { to: data.email_id },
        //   template: mailSender.htmlTemplates.PUJARI_CREATE__PUJARI,
        // });
      } catch (error) {
        console.log("error", error)
      }

      await transaction.commit();

      return { message: 'success' };
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }
  static async update(data, id, currentUser) {
    const transaction = await db.sequelize.transaction();
    try {
      let pujaris = await PujarisDBApi.findBy({ id }, { transaction });

      console.log('===== update pujari payload =====', data);

      if (!pujaris) {
        throw new ValidationError('pujarisNotFound');
      }
      await PujarisDBApi.update(id, data, {
        currentUser,
        transaction,
      });

      await Karuser_pujari_mappingsDBApi.remove(id, {
        currentUser,
        transaction,
      })

      const karusersPujariMappings = data?.karusers.map((user) => {
        return {
          pujari_id: id,
          karuser_id: user.id
        };
      })

      await Karuser_pujari_mappingsDBApi.create(karusersPujariMappings, {
        currentUser,
        transaction,
      })

      await transaction.commit();
      return pujaris;
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async remove(id, currentUser) {
    const transaction = await db.sequelize.transaction();

    try {
      // if (currentUser.role !== 'admin') {
      //   throw new ValidationError('errors.forbidden.message');
      // }

      await PujarisDBApi.remove(id, {
        currentUser,
        transaction,
      });

      await transaction.commit();
      return { message: 'success' };
    } catch (error) {
      await transaction.rollback();
      throw error;
    }
  }

  static async getPujariDetails(id) {
    try {
      const result = await PujarisDBApi.findPujari(id);
      return result
    } catch (error) {
      throw error;
    }
  }
};
